@@ -197,10 +197,13 @@ impl<'a> Btf<'a> {
                     _ => bail!("Invalid integer width"),
                 };
 
-                if t.encoding == btf::BtfIntEncoding::Signed {
-                    format!("i{}", width)
-                } else {
-                    format!("u{}", width)
+                match t.encoding {
+                    btf::BtfIntEncoding::Signed => format!("i{}", width),
+                    btf::BtfIntEncoding::Bool => {
+                        assert!(t.bits as usize == (std::mem::size_of::<bool>() * 8));
+                        format!("bool")
+                    }
+                    btf::BtfIntEncoding::Char | btf::BtfIntEncoding::None => format!("u{}", width),
                 }
             }
             BtfType::Ptr(t) => {
@@ -433,26 +436,23 @@ impl<'a> Btf<'a> {
                                     gen_impl_default = true
                                 }
                             }
-
-                            match self.type_default(field_ty_id) {
-                                Ok(def) => {
-                                    impl_default.push(format!(
-                                        r#"            {field_name}: {field_ty_str}"#,
-                                        field_name = member.name,
-                                        field_ty_str = def
-                                    ));
-                                }
-                                Err(e) => {
-                                    if gen_impl_default {
-                                        bail!(
-                                            "Could not construct a necessary Default Impl: {}",
-                                            e
-                                        );
-                                    }
-                                }
-                            };
                         }
 
+                        match self.type_default(field_ty_id) {
+                            Ok(def) => {
+                                impl_default.push(format!(
+                                    r#"            {field_name}: {field_ty_str}"#,
+                                    field_name = member.name,
+                                    field_ty_str = def
+                                ));
+                            }
+                            Err(e) => {
+                                if gen_impl_default || !t.is_struct {
+                                    bail!("Could not construct a necessary Default Impl: {}", e);
+                                }
+                            }
+                        };
+
                         // Set `offset` to end of current var
                         offset = ((member.bit_offset / 8) + self.size_of(field_ty_id)?) as usize;
 
@@ -508,6 +508,15 @@ impl<'a> Btf<'a> {
                         writeln!(def, r#"        write!(f, "(???)")"#)?;
                         writeln!(def, r#"    }}"#)?;
                         writeln!(def, r#"}}"#)?;
+
+                        // write a Default implementation for a union
+                        writeln!(def, r#"impl Default for {} {{"#, t.name)?;
+                        writeln!(def, r#"    fn default() -> Self {{"#)?;
+                        writeln!(def, r#"        {} {{"#, t.name)?;
+                        writeln!(def, r#"{},"#, impl_default[0])?;
+                        writeln!(def, r#"        }}"#)?;
+                        writeln!(def, r#"    }}"#)?;
+                        writeln!(def, r#"}}"#)?;
                     }
                 }
                 BtfType::Enum(t) => {
