@@ -665,7 +665,9 @@ fn gen_skel_contents(_debug: bool, raw_obj_name: &str, obj_file_path: &Path) ->
 
            #![allow(dead_code)]
            #![allow(non_snake_case)]
+           #![allow(non_camel_case_types)]
            #![allow(clippy::transmute_ptr_to_ref)]
+           #![allow(clippy::upper_case_acronyms)]
 
            use libbpf_rs::libbpf_sys;
         "#
