@@ -1280,6 +1280,13 @@ impl std::fmt::Debug for Foo {
         write!(f, "(???)")
     }
 }
+impl Default for Foo {
+    fn default() -> Self {
+        Foo {
+            x: i32::default(),
+        }
+    }
+}
 "#;
 
     let btf = build_btf_prog(prog_text);
@@ -1607,6 +1614,13 @@ impl std::fmt::Debug for __anon_1 {
         write!(f, "(???)")
     }
 }
+impl Default for __anon_1 {
+    fn default() -> Self {
+        __anon_1 {
+            y: [u8::default(); 10],
+        }
+    }
+}
 #[derive(Copy, Clone)]
 #[repr(C)]
 pub union __anon_2 {
@@ -1618,6 +1632,13 @@ impl std::fmt::Debug for __anon_2 {
         write!(f, "(???)")
     }
 }
+impl Default for __anon_2 {
+    fn default() -> Self {
+        __anon_2 {
+            w: u32::default(),
+        }
+    }
+}
 "#;
 
     let btf = build_btf_prog(prog_text);
@@ -1741,6 +1762,13 @@ impl std::fmt::Debug for __anon_2 {
         write!(f, "(???)")
     }
 }
+impl Default for __anon_2 {
+    fn default() -> Self {
+        __anon_2 {
+            a: std::ptr::null_mut(),
+        }
+    }
+}
 #[derive(Debug, Default, Copy, Clone)]
 #[repr(C)]
 pub struct __anon_3 {
@@ -1759,6 +1787,13 @@ impl std::fmt::Debug for __anon_4 {
         write!(f, "(???)")
     }
 }
+impl Default for __anon_4 {
+    fn default() -> Self {
+        __anon_4 {
+            c: u8::default(),
+        }
+    }
+}
 "#;
 
     let btf = build_btf_prog(prog_text);
@@ -1775,79 +1810,72 @@ fn test_btf_dump_definition_anon_enum() {
 #include "vmlinux.h"
 #include <bpf/bpf_helpers.h>
 
+typedef enum {
+    FOO = 1,
+} test_t;
 struct Foo {
-    int x;
-    struct {
-        u8 y[10];
-        u16 z[16];
-    } bar;
-    union {
-        char *a;
-        int b;
-    } zerg;
-    struct {
-        u32 w;
-        u64 *u;
-    } baz;
-    int w;
-    union {
-        u8 c;
-        u64 d[5];
-    } flarg;
+    test_t test;
 };
-
-struct Foo foo;"#;
+struct Foo foo;
+"#;
 
     let expected_output = r#"
 #[derive(Debug, Default, Copy, Clone)]
 #[repr(C)]
 pub struct Foo {
-    pub x: i32,
-    pub bar: __anon_1,
-    pub zerg: __anon_2,
-    pub baz: __anon_3,
-    pub w: i32,
-    __pad_76: [u8; 4],
-    pub flarg: __anon_4,
+    pub test: __anon_1,
 }
-#[derive(Debug, Default, Copy, Clone)]
-#[repr(C)]
-pub struct __anon_1 {
-    pub y: [u8; 10],
-    pub z: [u16; 16],
+#[derive(Debug, Copy, Clone, PartialEq)]
+#[repr(u32)]
+pub enum __anon_1 {
+    FOO = 1,
 }
-#[derive(Copy, Clone)]
-#[repr(C)]
-pub union __anon_2 {
-    pub a: *mut i8,
-    pub b: i32,
-}
-impl std::fmt::Debug for __anon_2 {
-    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
-        write!(f, "(???)")
-    }
-}
-#[derive(Debug, Default, Copy, Clone)]
-#[repr(C)]
-pub struct __anon_3 {
-    pub w: u32,
-    __pad_4: [u8; 4],
-    pub u: *mut u64,
-}
-#[derive(Copy, Clone)]
-#[repr(C)]
-pub union __anon_4 {
-    pub c: u8,
-    pub d: [u64; 5],
-}
-impl std::fmt::Debug for __anon_4 {
-    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
-        write!(f, "(???)")
+impl Default for __anon_1 {
+    fn default() -> Self {
+        __anon_1::FOO
     }
 }
 "#;
+
     let btf = build_btf_prog(prog_text);
 
+    // Find the struct
+    let struct_foo = find_type_in_btf!(btf, Struct, "Foo");
+
+    assert_definition(&btf, struct_foo, expected_output);
+}
+
+#[test]
+fn test_btf_dump_definition_int_encodings() {
+    let prog_text = r#"
+#include "vmlinux.h"
+#include <bpf/bpf_helpers.h>
+
+struct Foo {
+    s32 a;
+    u16 b;
+    s16 c;
+    bool d;
+    char e;
+};
+struct Foo foo;
+"#;
+
+    let expected_output = r#"
+#[derive(Debug, Default, Copy, Clone)]
+#[repr(C)]
+pub struct Foo {
+    pub a: i32,
+    pub b: u16,
+    pub c: i16,
+    pub d: bool,
+    pub e: i8,
+}
+"#;
+
+    let btf = build_btf_prog(prog_text);
+
+    // Find the struct
     let struct_foo = find_type_in_btf!(btf, Struct, "Foo");
 
     assert_definition(&btf, struct_foo, expected_output);
